@@ -1,7 +1,7 @@
 from datetime import datetime,date,timedelta
 from dateutil.relativedelta import relativedelta
 
-from ezhelper import *
+from .ezhelper import *
 
 
 def fn_today(format='.'):
